@@ -3,7 +3,7 @@ package Chart::OFC;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Moose 0.56;
 use MooseX::StrictConstructor;
@@ -26,7 +26,6 @@ has title_style =>
 has tool_tip =>
     ( is        => 'ro',
       isa       => 'Str',
-      optional  => 1,
       predicate => '_has_tool_tip',
     );
 
@@ -34,7 +33,6 @@ has bg_color =>
     ( is        => 'ro',
       isa       => 'Chart::OFC::Type::Color',
       coerce    => 1,
-      optional  => 1,
       predicate => '_has_bg_color',
     );
 
@@ -284,14 +282,33 @@ This distribution does not yet support all of the features of OFC.
 There are a few items left to do, notably grid charts with 2 Y axes,
 and background images.
 
-There are some new chart types in OFC 1.9.5 which are not supported.
-
 It would also be nice to generate embeddable Javascript for populating
 charts, since this lets you create a chart without making an
 additional server request for the data.
 
 Patches are welcome.
 
+=head1 DONATIONS
+
+If you'd like to thank me for the work I've done on this module,
+please consider making a "donation" to me via PayPal. I spend a lot of
+free time creating free software, and would appreciate any support
+you'd care to offer.
+
+Please note that B<I am not suggesting that you must do this> in order
+for me to continue working on this particular software. I will
+continue to do so, inasmuch as I have in the past, for as long as it
+interests me.
+
+Similarly, a donation made in this way will probably not make me work
+on this software much more, unless I get so many donations that I can
+consider working on free software full time, which seems unlikely at
+best.
+
+To donate, log into PayPal and send money to autarch@urth.org or use
+the button on this page:
+L<http://www.urth.org/~autarch/fs-donation.html>
+
 =head1 AUTHOR
 
 Dave Rolsky, C<< <autarch@urth.org> >>
